# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .response_format_type import ResponseFormatType


class ResponseFormat(UniversalBaseModel):
    """
    Specifies the format of the response. When you omit this parameter, the platform returns unstructured text.
    """

    type: ResponseFormatType = pydantic.Field()
    """
    Set this parameter to "json_schema" to receive structured JSON responses.
    """

    json_schema: typing.Dict[str, typing.Optional[typing.Any]] = pydantic.Field()
    """
    Contains the JSON schema that defines the response structure. The schema must adhere to the [JSON Schema Draft 2020-12](https://json-schema.org/draft/2020-12) specification.
    
    **Supported types**
    - `array`
    - `boolean`
    - `integer`
    - `null`
    - `number`
    - `object`
    - `string`
    
    **Supported constraints**
    
    | Type | Supported keywords | Notes |
    |------|-------------------|-------|
    | `integer` | `maximum`, `exclusiveMaximum`, `minimum`, `exclusiveMinimum`. | - `maximum`: Sets the highest allowed value (inclusive).<br/>- `exclusiveMaximum`: Sets the highest allowed value (exclusive).<br/>-`minimum`: Sets the lowest allowed value (inclusive).<br/>- `exclusiveMinimum`: Sets the lowest allowed value (exclusive).<br/>These constraints are supported only for the `integer` type. |
    | `string` | `pattern`, `format` | - `pattern`: A regular expression that the string must match.<br/>- `format`: Validates predefined formats. It accepts the following values: `uuid`, `date-time`, `date`, and `time`.<br/>See string limitations below. |
    | `object` | `properties`, `required` | - `properties`: Defines object properties and their schemas. - `required`: Specifies mandatory properties.<br/>See object limitations below. |
    | `array` | `items`, `minItems` | `minItems` accepts only `0` or `1` |
    
    
    **String limitations**
    
    The platform validates strings using the `pattern` and `format` constraints only. When you include `minLength` or `maxLength` keywords in your schema, the platform returns an error: "String length constraints (minLength) are not supported."
    
    
    **Object limitations**
    
    When you use the `object` type:
    - The platform always ignores the `additionalProperties` setting.
    - The sequence of the properties is fixed.
    - The first property should be required. If the first property is optional, the platform moves the first required property to the first position.
    
    
    **Constant and enumerated values**
    
    The `const` and `enum` keywords support the following types:
    - `boolean`
    - `null`
    - `number`
    - `string`
    
    
    **Schema composition**
    
    The platform supports only `anyOf` for [schema composition](https://json-schema.org/understanding-json-schema/reference/combining).
    
    
    **Annotations**
    
    The platform accepts but ignores JSON schema annotations like `title`, `$comments`, and `description`.
    
    **Subschema references**
    
    You can reference subschemas using `$ref` with these requirements:
    - Define subschemas within `$defs`.
    - Use valid URIs that point to the internal subschema.
    
    For details, see the [JSON Schema documentation on $defs](https://json-schema.org/understanding-json-schema/structuring#defs).
    
    
    
    **Response validation**
    
    Check the `FinishReason` field to verify your JSON response is complete:
    - When `FinishReason` is `stop`, the generation completed normally, and the JSON is valid and complete.
    - When `FinishReason` is `length`, the platform truncates the response at the token limit. This may result in truncated, invalid JSON that fails to parse.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import httpx
from .analyze_async.client import AnalyzeAsyncClient, AsyncAnalyzeAsyncClient
from .assets.client import AssetsClient, AsyncAssetsClient
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.request_options import RequestOptions
from .embed.client import AsyncEmbedClient, EmbedClient
from .entity_collections.client import AsyncEntityCollectionsClient, EntityCollectionsClient
from .environment import TwelveLabsEnvironment
from .indexes.client import AsyncIndexesClient, IndexesClient
from .multipart_upload.client import AsyncMultipartUploadClient, MultipartUploadClient
from .raw_base_client import AsyncRawBaseClient, RawBaseClient
from .search.client import AsyncSearchClient, SearchClient
from .tasks.client import AsyncTasksClient, TasksClient
from .types.analyze_max_tokens import AnalyzeMaxTokens
from .types.analyze_temperature import AnalyzeTemperature
from .types.analyze_text_prompt import AnalyzeTextPrompt
from .types.non_stream_analyze_response import NonStreamAnalyzeResponse
from .types.response_format import ResponseFormat
from .types.stream_analyze_response import StreamAnalyzeResponse
from .types.video_context import VideoContext

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class BaseClient:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : TwelveLabsEnvironment
        The environment to use for requests from the client. from .environment import TwelveLabsEnvironment



        Defaults to TwelveLabsEnvironment.DEFAULT



    api_key : str
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from twelvelabs import TwelveLabs

    client = TwelveLabs(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: TwelveLabsEnvironment = TwelveLabsEnvironment.DEFAULT,
        api_key: str,
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._raw_client = RawBaseClient(client_wrapper=self._client_wrapper)
        self.tasks = TasksClient(client_wrapper=self._client_wrapper)
        self.indexes = IndexesClient(client_wrapper=self._client_wrapper)
        self.assets = AssetsClient(client_wrapper=self._client_wrapper)
        self.multipart_upload = MultipartUploadClient(client_wrapper=self._client_wrapper)
        self.entity_collections = EntityCollectionsClient(client_wrapper=self._client_wrapper)
        self.embed = EmbedClient(client_wrapper=self._client_wrapper)
        self.search = SearchClient(client_wrapper=self._client_wrapper)
        self.analyze_async = AnalyzeAsyncClient(client_wrapper=self._client_wrapper)

    @property
    def with_raw_response(self) -> RawBaseClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawBaseClient
        """
        return self._raw_client

    def analyze_stream(
        self,
        *,
        prompt: AnalyzeTextPrompt,
        video_id: typing.Optional[str] = OMIT,
        video: typing.Optional[VideoContext] = OMIT,
        temperature: typing.Optional[AnalyzeTemperature] = OMIT,
        response_format: typing.Optional[ResponseFormat] = OMIT,
        max_tokens: typing.Optional[AnalyzeMaxTokens] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[StreamAnalyzeResponse]:
        """
        This method synchronously analyzes your videos and generates fully customizable text based on your prompts.

        <Accordion title="Input requirements">
        - Minimum duration: 4 seconds
        - Maximum duration: 1 hour
        - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
        - Resolution: 360x360 to 5184x2160 pixels
        - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1.
        </Accordion>

        **When to use this method**:
        - Analyze videos up to 1 hour
        - Retrieve immediate results without waiting for asynchronous processing
        - Stream text fragments in real-time for immediate processing and feedback

        **Do not use this method for**:
        - Videos longer than 1 hour. Use the [`POST`](/v1.3/api-reference/analyze-videos/create-async-analysis-task) method of the `/analyze/tasks` endpoint instead.

        <Note title="Notes">
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        prompt : AnalyzeTextPrompt

        video_id : typing.Optional[str]
            The unique identifier of the video to analyze.

            <Info> This parameter will be deprecated and removed in a future version. Use the [`video`](/v1.3/api-reference/analyze-videos/sync-analysis#request.body.video) parameter instead.</Info>

        video : typing.Optional[VideoContext]

        temperature : typing.Optional[AnalyzeTemperature]

        response_format : typing.Optional[ResponseFormat]

        max_tokens : typing.Optional[AnalyzeMaxTokens]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.Iterator[StreamAnalyzeResponse]


        Examples
        --------
        from twelvelabs import ResponseFormat, TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        response = client.analyze_stream(
            video_id="6298d673f1090f1100476d4c",
            prompt="I want to generate a description for my video with the following format - Title of the video, followed by a summary in 2-3 sentences, highlighting the main topic, key events, and concluding remarks.",
            temperature=0.2,
            response_format=ResponseFormat(
                type="json_schema",
                json_schema={
                    "type": "object",
                    "properties": {
                        "title": {"type": "string"},
                        "summary": {"type": "string"},
                        "keywords": {"type": "array", "items": {"type": "string"}},
                    },
                },
            ),
            max_tokens=2000,
        )
        for chunk in response:
            yield chunk
        """
        with self._raw_client.analyze_stream(
            prompt=prompt,
            video_id=video_id,
            video=video,
            temperature=temperature,
            response_format=response_format,
            max_tokens=max_tokens,
            request_options=request_options,
        ) as r:
            yield from r.data

    def analyze(
        self,
        *,
        prompt: AnalyzeTextPrompt,
        video_id: typing.Optional[str] = OMIT,
        video: typing.Optional[VideoContext] = OMIT,
        temperature: typing.Optional[AnalyzeTemperature] = OMIT,
        response_format: typing.Optional[ResponseFormat] = OMIT,
        max_tokens: typing.Optional[AnalyzeMaxTokens] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> NonStreamAnalyzeResponse:
        """
        This method synchronously analyzes your videos and generates fully customizable text based on your prompts.

        <Accordion title="Input requirements">
        - Minimum duration: 4 seconds
        - Maximum duration: 1 hour
        - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
        - Resolution: 360x360 to 5184x2160 pixels
        - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1.
        </Accordion>

        **When to use this method**:
        - Analyze videos up to 1 hour
        - Retrieve immediate results without waiting for asynchronous processing
        - Stream text fragments in real-time for immediate processing and feedback

        **Do not use this method for**:
        - Videos longer than 1 hour. Use the [`POST`](/v1.3/api-reference/analyze-videos/create-async-analysis-task) method of the `/analyze/tasks` endpoint instead.

        <Note title="Notes">
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        prompt : AnalyzeTextPrompt

        video_id : typing.Optional[str]
            The unique identifier of the video to analyze.

            <Info> This parameter will be deprecated and removed in a future version. Use the [`video`](/v1.3/api-reference/analyze-videos/sync-analysis#request.body.video) parameter instead.</Info>

        video : typing.Optional[VideoContext]

        temperature : typing.Optional[AnalyzeTemperature]

        response_format : typing.Optional[ResponseFormat]

        max_tokens : typing.Optional[AnalyzeMaxTokens]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        NonStreamAnalyzeResponse


        Examples
        --------
        from twelvelabs import ResponseFormat, TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.analyze(
            video_id="6298d673f1090f1100476d4c",
            prompt="I want to generate a description for my video with the following format - Title of the video, followed by a summary in 2-3 sentences, highlighting the main topic, key events, and concluding remarks.",
            temperature=0.2,
            response_format=ResponseFormat(
                type="json_schema",
                json_schema={
                    "type": "object",
                    "properties": {
                        "title": {"type": "string"},
                        "summary": {"type": "string"},
                        "keywords": {"type": "array", "items": {"type": "string"}},
                    },
                },
            ),
            max_tokens=2000,
        )
        """
        _response = self._raw_client.analyze(
            prompt=prompt,
            video_id=video_id,
            video=video,
            temperature=temperature,
            response_format=response_format,
            max_tokens=max_tokens,
            request_options=request_options,
        )
        return _response.data


class AsyncBaseClient:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : TwelveLabsEnvironment
        The environment to use for requests from the client. from .environment import TwelveLabsEnvironment



        Defaults to TwelveLabsEnvironment.DEFAULT



    api_key : str
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from twelvelabs import AsyncTwelveLabs

    client = AsyncTwelveLabs(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: TwelveLabsEnvironment = TwelveLabsEnvironment.DEFAULT,
        api_key: str,
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._raw_client = AsyncRawBaseClient(client_wrapper=self._client_wrapper)
        self.tasks = AsyncTasksClient(client_wrapper=self._client_wrapper)
        self.indexes = AsyncIndexesClient(client_wrapper=self._client_wrapper)
        self.assets = AsyncAssetsClient(client_wrapper=self._client_wrapper)
        self.multipart_upload = AsyncMultipartUploadClient(client_wrapper=self._client_wrapper)
        self.entity_collections = AsyncEntityCollectionsClient(client_wrapper=self._client_wrapper)
        self.embed = AsyncEmbedClient(client_wrapper=self._client_wrapper)
        self.search = AsyncSearchClient(client_wrapper=self._client_wrapper)
        self.analyze_async = AsyncAnalyzeAsyncClient(client_wrapper=self._client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawBaseClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawBaseClient
        """
        return self._raw_client

    async def analyze_stream(
        self,
        *,
        prompt: AnalyzeTextPrompt,
        video_id: typing.Optional[str] = OMIT,
        video: typing.Optional[VideoContext] = OMIT,
        temperature: typing.Optional[AnalyzeTemperature] = OMIT,
        response_format: typing.Optional[ResponseFormat] = OMIT,
        max_tokens: typing.Optional[AnalyzeMaxTokens] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[StreamAnalyzeResponse]:
        """
        This method synchronously analyzes your videos and generates fully customizable text based on your prompts.

        <Accordion title="Input requirements">
        - Minimum duration: 4 seconds
        - Maximum duration: 1 hour
        - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
        - Resolution: 360x360 to 5184x2160 pixels
        - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1.
        </Accordion>

        **When to use this method**:
        - Analyze videos up to 1 hour
        - Retrieve immediate results without waiting for asynchronous processing
        - Stream text fragments in real-time for immediate processing and feedback

        **Do not use this method for**:
        - Videos longer than 1 hour. Use the [`POST`](/v1.3/api-reference/analyze-videos/create-async-analysis-task) method of the `/analyze/tasks` endpoint instead.

        <Note title="Notes">
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        prompt : AnalyzeTextPrompt

        video_id : typing.Optional[str]
            The unique identifier of the video to analyze.

            <Info> This parameter will be deprecated and removed in a future version. Use the [`video`](/v1.3/api-reference/analyze-videos/sync-analysis#request.body.video) parameter instead.</Info>

        video : typing.Optional[VideoContext]

        temperature : typing.Optional[AnalyzeTemperature]

        response_format : typing.Optional[ResponseFormat]

        max_tokens : typing.Optional[AnalyzeMaxTokens]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.AsyncIterator[StreamAnalyzeResponse]


        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs, ResponseFormat

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            response = await client.analyze_stream(
                video_id="6298d673f1090f1100476d4c",
                prompt="I want to generate a description for my video with the following format - Title of the video, followed by a summary in 2-3 sentences, highlighting the main topic, key events, and concluding remarks.",
                temperature=0.2,
                response_format=ResponseFormat(
                    type="json_schema",
                    json_schema={
                        "type": "object",
                        "properties": {
                            "title": {"type": "string"},
                            "summary": {"type": "string"},
                            "keywords": {"type": "array", "items": {"type": "string"}},
                        },
                    },
                ),
                max_tokens=2000,
            )
            async for chunk in response:
                yield chunk


        asyncio.run(main())
        """
        async with self._raw_client.analyze_stream(
            prompt=prompt,
            video_id=video_id,
            video=video,
            temperature=temperature,
            response_format=response_format,
            max_tokens=max_tokens,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk

    async def analyze(
        self,
        *,
        prompt: AnalyzeTextPrompt,
        video_id: typing.Optional[str] = OMIT,
        video: typing.Optional[VideoContext] = OMIT,
        temperature: typing.Optional[AnalyzeTemperature] = OMIT,
        response_format: typing.Optional[ResponseFormat] = OMIT,
        max_tokens: typing.Optional[AnalyzeMaxTokens] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> NonStreamAnalyzeResponse:
        """
        This method synchronously analyzes your videos and generates fully customizable text based on your prompts.

        <Accordion title="Input requirements">
        - Minimum duration: 4 seconds
        - Maximum duration: 1 hour
        - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
        - Resolution: 360x360 to 5184x2160 pixels
        - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1.
        </Accordion>

        **When to use this method**:
        - Analyze videos up to 1 hour
        - Retrieve immediate results without waiting for asynchronous processing
        - Stream text fragments in real-time for immediate processing and feedback

        **Do not use this method for**:
        - Videos longer than 1 hour. Use the [`POST`](/v1.3/api-reference/analyze-videos/create-async-analysis-task) method of the `/analyze/tasks` endpoint instead.

        <Note title="Notes">
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        prompt : AnalyzeTextPrompt

        video_id : typing.Optional[str]
            The unique identifier of the video to analyze.

            <Info> This parameter will be deprecated and removed in a future version. Use the [`video`](/v1.3/api-reference/analyze-videos/sync-analysis#request.body.video) parameter instead.</Info>

        video : typing.Optional[VideoContext]

        temperature : typing.Optional[AnalyzeTemperature]

        response_format : typing.Optional[ResponseFormat]

        max_tokens : typing.Optional[AnalyzeMaxTokens]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        NonStreamAnalyzeResponse


        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs, ResponseFormat

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.analyze(
                video_id="6298d673f1090f1100476d4c",
                prompt="I want to generate a description for my video with the following format - Title of the video, followed by a summary in 2-3 sentences, highlighting the main topic, key events, and concluding remarks.",
                temperature=0.2,
                response_format=ResponseFormat(
                    type="json_schema",
                    json_schema={
                        "type": "object",
                        "properties": {
                            "title": {"type": "string"},
                            "summary": {"type": "string"},
                            "keywords": {"type": "array", "items": {"type": "string"}},
                        },
                    },
                ),
                max_tokens=2000,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.analyze(
            prompt=prompt,
            video_id=video_id,
            video=video,
            temperature=temperature,
            response_format=response_format,
            max_tokens=max_tokens,
            request_options=request_options,
        )
        return _response.data


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: TwelveLabsEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class IndexesCreateRequestModelsItem(UniversalBaseModel):
    model_name: str = pydantic.Field()
    """
    The name of the model. The following models are available:
    
      - **Embedding**: These models are proficient at performing tasks such as search and classification, enabling enhanced video understanding.
    
        - `marengo3.0`: Enhanced model with sports intelligence and extended content support.
    
      - **Generative**: These models generate text based on your videos.
    
        - `pegasus1.2`: A model that analyzes multiple modalities to generate contextually relevant text based on the content of your videos.
    
    <Note title="Note">
    You cannot change the model configuration once the index has been created.
    </Note>
    """

    model_options: typing.List[str] = pydantic.Field()
    """
    An array that specifies which modalities the platform analyzes. For the Marengo and Pegasus models, you can specify one or both of the following model options: `visual` and `audio`. For more details, see the [Model options](/v1.3/docs/concepts/modalities#model-options) section.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .indexed_assets_create_response import IndexedAssetsCreateResponse
from .indexed_assets_list_request_status_item import IndexedAssetsListRequestStatusItem
from .indexed_assets_list_request_user_metadata_value import IndexedAssetsListRequestUserMetadataValue
from .indexed_assets_list_response import IndexedAssetsListResponse
from .indexed_assets_retrieve_request_embedding_option_item import IndexedAssetsRetrieveRequestEmbeddingOptionItem

__all__ = [
    "IndexedAssetsCreateResponse",
    "IndexedAssetsListRequestStatusItem",
    "IndexedAssetsListRequestUserMetadataValue",
    "IndexedAssetsListResponse",
    "IndexedAssetsRetrieveRequestEmbeddingOptionItem",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .created_at import CreatedAt
from .embedding_data import EmbeddingData
from .embedding_task_media_metadata import EmbeddingTaskMediaMetadata
from .embedding_task_response_status import EmbeddingTaskResponseStatus
from .updated_at import UpdatedAt


class EmbeddingTaskResponse(UniversalBaseModel):
    """
    An object containing the status of the embedding task and the embeddings (when ready).
    """

    id: typing_extensions.Annotated[str, FieldMetadata(alias="_id")] = pydantic.Field()
    """
    The unique identifier of the embedding task.
    """

    status: EmbeddingTaskResponseStatus = pydantic.Field()
    """
    The current status of the task.
    
    
    **Values**:
    - `processing`: The platform is creating the embeddings
    - `ready`: Processing is complete. Embeddings are available in the `data` field
    - `failed`: The task failed. The `data` field is `null`
    """

    created_at: typing.Optional[CreatedAt] = None
    updated_at: typing.Optional[UpdatedAt] = None
    data: typing.Optional[typing.List[EmbeddingData]] = pydantic.Field(default=None)
    """
    An object containing the embedding results, or `null` otherwise.
    """

    metadata: typing.Optional[EmbeddingTaskMediaMetadata] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .analyze_task_result_usage import AnalyzeTaskResultUsage
from .finish_reason import FinishReason
from .generated_text_data import GeneratedTextData


class AnalyzeTaskResult(UniversalBaseModel):
    """
    The analysis results for a completed task.
    """

    generation_id: str = pydantic.Field()
    """
    The unique identifier for the generation session.
    """

    data: GeneratedTextData
    finish_reason: FinishReason
    usage: AnalyzeTaskResultUsage = pydantic.Field()
    """
    The number of tokens used in the generation.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pagination import AsyncPager, BaseHttpResponse, SyncPager
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.bad_request_error import BadRequestError
from ..types.entity_collection import EntityCollection
from .types.entity_collections_list_request_sort_by import EntityCollectionsListRequestSortBy
from .types.entity_collections_list_response import EntityCollectionsListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawEntityCollectionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        page: typing.Optional[int] = None,
        page_limit: typing.Optional[int] = None,
        name: typing.Optional[str] = None,
        sort_by: typing.Optional[EntityCollectionsListRequestSortBy] = None,
        sort_option: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[EntityCollection]:
        """
        This method returns a list of the entity collections in your account.

        Parameters
        ----------
        page : typing.Optional[int]
            A number that identifies the page to retrieve.

            **Default**: `1`.

        page_limit : typing.Optional[int]
            The number of items to return on each page.

            **Default**: `10`.
            **Max**: `50`.

        name : typing.Optional[str]
            Filter entity collections by name.

        sort_by : typing.Optional[EntityCollectionsListRequestSortBy]
            The field to sort on. The following options are available:
            - `created_at`: Sorts by the time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when the entity collection was updated.
            - `updated_at`: Sorts by the time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when the entity collection was created.
            - `name`: Sorts by the name.

        sort_option : typing.Optional[str]
            The sorting direction. The following options are available:
            - `asc`
            - `desc`

            **Default**: `desc`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[EntityCollection]
            The entity collections have been successfully retrieved.
        """
        page = page if page is not None else 1

        _response = self._client_wrapper.httpx_client.request(
            "entity-collections",
            method="GET",
            params={
                "page": page,
                "page_limit": page_limit,
                "name": name,
                "sort_by": sort_by,
                "sort_option": sort_option,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _parsed_response = typing.cast(
                    EntityCollectionsListResponse,
                    parse_obj_as(
                        type_=EntityCollectionsListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                _items = _parsed_response.data
                _has_next = True
                _get_next = lambda: self.list(
                    page=page + 1,
                    page_limit=page_limit,
                    name=name,
                    sort_by=sort_by,
                    sort_option=sort_option,
                    request_options=request_options,
                )
                return SyncPager(
                    has_next=_has_next, items=_items, get_next=_get_next, response=BaseHttpResponse(response=_response)
                )
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        *,
        name: str,
        description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[EntityCollection]:
        """
        This method creates an entity collection.

        Parameters
        ----------
        name : str
            The name of the entity collection. Make sure you use a succinct and descriptive name.

        description : typing.Optional[str]
            Optional description of the entity collection.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EntityCollection]
            The entity collection has been successfully created.
        """
        _response = self._client_wrapper.httpx_client.request(
            "entity-collections",
            method="POST",
            json={
                "name": name,
                "description": description,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EntityCollection,
                    parse_obj_as(
                        type_=EntityCollection,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def retrieve(
        self, entity_collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[EntityCollection]:
        """
        This method retrieves details about the specified entity collection.

        Parameters
        ----------
        entity_collection_id : str
            The unique identifier of the entity collection to retrieve.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EntityCollection]
            The entity collection has been successfully retrieved.
        """
        _response = self._client_wrapper.httpx_client.request(
            f"entity-collections/{jsonable_encoder(entity_collection_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EntityCollection,
                    parse_obj_as(
                        type_=EntityCollection,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, entity_collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[None]:
        """
        This method deletes the specified entity collection. This action cannot be undone.

        Parameters
        ----------
        entity_collection_id : str
            The unique identifier of the entity collection to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"entity-collections/{jsonable_encoder(entity_collection_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        entity_collection_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[EntityCollection]:
        """
        This method updates the specified entity collection.

        Parameters
        ----------
        entity_collection_id : str
            The unique identifier of the entity collection to update.

        name : typing.Optional[str]
            The updated name of the entity collection.

        description : typing.Optional[str]
            The updated description of the entity collection.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EntityCollection]
            The entity collection has been successfully updated.
        """
        _response = self._client_wrapper.httpx_client.request(
            f"entity-collections/{jsonable_encoder(entity_collection_id)}",
            method="PATCH",
            json={
                "name": name,
                "description": description,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EntityCollection,
                    parse_obj_as(
                        type_=EntityCollection,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawEntityCollectionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        page: typing.Optional[int] = None,
        page_limit: typing.Optional[int] = None,
        name: typing.Optional[str] = None,
        sort_by: typing.Optional[EntityCollectionsListRequestSortBy] = None,
        sort_option: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[EntityCollection]:
        """
        This method returns a list of the entity collections in your account.

        Parameters
        ----------
        page : typing.Optional[int]
            A number that identifies the page to retrieve.

            **Default**: `1`.

        page_limit : typing.Optional[int]
            The number of items to return on each page.

            **Default**: `10`.
            **Max**: `50`.

        name : typing.Optional[str]
            Filter entity collections by name.

        sort_by : typing.Optional[EntityCollectionsListRequestSortBy]
            The field to sort on. The following options are available:
            - `created_at`: Sorts by the time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when the entity collection was updated.
            - `updated_at`: Sorts by the time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when the entity collection was created.
            - `name`: Sorts by the name.

        sort_option : typing.Optional[str]
            The sorting direction. The following options are available:
            - `asc`
            - `desc`

            **Default**: `desc`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[EntityCollection]
            The entity collections have been successfully retrieved.
        """
        page = page if page is not None else 1

        _response = await self._client_wrapper.httpx_client.request(
            "entity-collections",
            method="GET",
            params={
                "page": page,
                "page_limit": page_limit,
                "name": name,
                "sort_by": sort_by,
                "sort_option": sort_option,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _parsed_response = typing.cast(
                    EntityCollectionsListResponse,
                    parse_obj_as(
                        type_=EntityCollectionsListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                _items = _parsed_response.data
                _has_next = True

                async def _get_next():
                    return await self.list(
                        page=page + 1,
                        page_limit=page_limit,
                        name=name,
                        sort_by=sort_by,
                        sort_option=sort_option,
                        request_options=request_options,
                    )

                return AsyncPager(
                    has_next=_has_next, items=_items, get_next=_get_next, response=BaseHttpResponse(response=_response)
                )
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        *,
        name: str,
        description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[EntityCollection]:
        """
        This method creates an entity collection.

        Parameters
        ----------
        name : str
            The name of the entity collection. Make sure you use a succinct and descriptive name.

        description : typing.Optional[str]
            Optional description of the entity collection.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EntityCollection]
            The entity collection has been successfully created.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "entity-collections",
            method="POST",
            json={
                "name": name,
                "description": description,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EntityCollection,
                    parse_obj_as(
                        type_=EntityCollection,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def retrieve(
        self, entity_collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[EntityCollection]:
        """
        This method retrieves details about the specified entity collection.

        Parameters
        ----------
        entity_collection_id : str
            The unique identifier of the entity collection to retrieve.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EntityCollection]
            The entity collection has been successfully retrieved.
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"entity-collections/{jsonable_encoder(entity_collection_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EntityCollection,
                    parse_obj_as(
                        type_=EntityCollection,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, entity_collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[None]:
        """
        This method deletes the specified entity collection. This action cannot be undone.

        Parameters
        ----------
        entity_collection_id : str
            The unique identifier of the entity collection to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"entity-collections/{jsonable_encoder(entity_collection_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        entity_collection_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[EntityCollection]:
        """
        This method updates the specified entity collection.

        Parameters
        ----------
        entity_collection_id : str
            The unique identifier of the entity collection to update.

        name : typing.Optional[str]
            The updated name of the entity collection.

        description : typing.Optional[str]
            The updated description of the entity collection.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EntityCollection]
            The entity collection has been successfully updated.
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"entity-collections/{jsonable_encoder(entity_collection_id)}",
            method="PATCH",
            json={
                "name": name,
                "description": description,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EntityCollection,
                    parse_obj_as(
                        type_=EntityCollection,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .entity_status import EntityStatus


class Entity(UniversalBaseModel):
    """
    An object that represents an entity with associated assets.
    """

    id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="_id")] = pydantic.Field(default=None)
    """
    The unique identifier of the entity.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the entity.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    A description of the entity.
    """

    metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Custom metadata for the entity.
    """

    asset_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    An array of asset IDs associated with the entity.
    """

    status: typing.Optional[EntityStatus] = pydantic.Field(default=None)
    """
    The current status of the entity creation process.
    
    **Values**:
    - `processing`: The entity is being processed and is not yet ready for use in searches.
    - `ready`: The entity is fully processed and can be used in search queries.
    """

    created_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The date and time, in RFC 3339 format (“YYYY-MM-DDTHH:mm:ssZ”), when the entity was created.
    """

    updated_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The date and time, in RFC 3339 format (“YYYY-MM-DDTHH:mm:ssZ”), when the entity was last updated.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .finish_reason import FinishReason
from .generated_text_data import GeneratedTextData
from .token_usage import TokenUsage


class NonStreamAnalyzeResponse(UniversalBaseModel):
    """
    When the value of the `stream` parameter is set to `false`, the response is as follows:
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier of the response.
    """

    data: typing.Optional[GeneratedTextData] = None
    finish_reason: typing.Optional[FinishReason] = None
    usage: typing.Optional[TokenUsage] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .multi_input_media_source import MultiInputMediaSource


class MultiInputRequest(UniversalBaseModel):
    """
    This field is required if the `input_type` parameter is `multi_input`.
    """

    input_text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Text to combine with the images when generating the embedding.
    
    **Usage options**:
    - Omit this field to create an embedding from images only.
    - Provide plain text to add context. Example: "A person cooking."
    - Use image references to describe relationships between specific images. The format is `<@name>`, where `name` matches the `name` field of a media source. Example: "A person wearing <@outfit> and holding <@accessory>."
    """

    media_sources: typing.List[MultiInputMediaSource] = pydantic.Field()
    """
    An array of up to 10 images to include in the embedding. The platform processes images in the order they appear in the array. If you use image references in the [`input_text`](/v1.3/api-reference/create-embeddings-v2/create-embeddings#request.body.multi_input.input_text) parameter, each must have a corresponding image with a matching `name` field. If an image reference has no match, the request fails.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    VideosListRequestUserMetadataValue,
    VideosListResponse,
    VideosRetrieveRequestEmbeddingOptionItem,
    VideosRetrieveResponse,
    VideosRetrieveResponseEmbedding,
    VideosRetrieveResponseEmbeddingVideoEmbedding,
    VideosRetrieveResponseSystemMetadata,
)

__all__ = [
    "VideosListRequestUserMetadataValue",
    "VideosListResponse",
    "VideosRetrieveRequestEmbeddingOptionItem",
    "VideosRetrieveResponse",
    "VideosRetrieveResponseEmbedding",
    "VideosRetrieveResponseEmbeddingVideoEmbedding",
    "VideosRetrieveResponseSystemMetadata",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.pagination import AsyncPager, SyncPager
from ....core.request_options import RequestOptions
from ....types.audio_input_request import AudioInputRequest
from ....types.embedding_task_response import EmbeddingTaskResponse
from ....types.media_embedding_task import MediaEmbeddingTask
from ....types.video_input_request import VideoInputRequest
from .raw_client import AsyncRawTasksClient, RawTasksClient
from .types.create_async_embedding_request_input_type import CreateAsyncEmbeddingRequestInputType
from .types.create_async_embedding_request_model_name import CreateAsyncEmbeddingRequestModelName
from .types.tasks_create_response import TasksCreateResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TasksClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTasksClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTasksClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTasksClient
        """
        return self._raw_client

    def list(
        self,
        *,
        started_at: typing.Optional[str] = None,
        ended_at: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        page: typing.Optional[int] = None,
        page_limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[MediaEmbeddingTask]:
        """
        This method returns a list of the async embedding tasks in your account. The platform returns your async embedding tasks sorted by creation date, with the newest at the top of the list.

        Parameters
        ----------
        started_at : typing.Optional[str]
            Retrieve the embedding tasks that were created after the given date and time, expressed in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ").

        ended_at : typing.Optional[str]
            Retrieve the embedding tasks that were created before the given date and time, expressed in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ").

        status : typing.Optional[str]
            Filter the embedding tasks by their current status.

            **Values**: `processing`, `ready`, or `failed`.

        page : typing.Optional[int]
            A number that identifies the page to retrieve.

            **Default**: `1`.

        page_limit : typing.Optional[int]
            The number of items to return on each page.

            **Default**: `10`.
            **Max**: `50`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[MediaEmbeddingTask]
            A list of async embedding tasks has successfully been retrieved.

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        response = client.embed.v_2.tasks.list(
            started_at="2024-03-01T00:00:00Z",
            ended_at="2024-03-01T00:00:00Z",
            status="processing",
            page=1,
            page_limit=10,
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.list(
            started_at=started_at,
            ended_at=ended_at,
            status=status,
            page=page,
            page_limit=page_limit,
            request_options=request_options,
        )

    def create(
        self,
        *,
        input_type: CreateAsyncEmbeddingRequestInputType,
        model_name: CreateAsyncEmbeddingRequestModelName,
        audio: typing.Optional[AudioInputRequest] = OMIT,
        video: typing.Optional[VideoInputRequest] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TasksCreateResponse:
        """
        This endpoint creates embeddings for audio and video content asynchronously.

        **When to use this endpoint**:
        - Process audio or video files longer than 10 minutes
        - Process files up to 4 hours in duration

        <Accordion title="Input requirements">
          **Video**:
          - Minimum duration: 4 seconds
          - Maximum duration: 4 hours
          - Maximum file size: 4 GB
          - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
          - Resolution: 360x360 to 5184x2160 pixels
          - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1

          **Audio**:
          - Minimum duration: 4 seconds
          - Maximum duration: 4 hours
          - Maximum file size: 2 GB
          - Formats: WAV (uncompressed), MP3 (lossy), FLAC (lossless)
        </Accordion>

          Creating embeddings asynchronously requires three steps:

          1. Create a task using this endpoint. The platform returns a task ID.
          2. Poll for the status of the task using the [`GET`](/v1.3/api-reference/create-embeddings-v2/retrieve-embeddings) method of the `/embed-v2/tasks/{task_id}` endpoint. Wait until the status is `ready`.
          3. Retrieve the embeddings from the response when the status is `ready` using the [`GET`](/v1.3/api-reference/create-embeddings-v2/retrieve-embeddings) method of the `/embed-v2/tasks/{task_id}` endpoint.

          <Note title="Note">
          This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
          </Note>

        Parameters
        ----------
        input_type : CreateAsyncEmbeddingRequestInputType
            The type of content for the embeddings.

            **Values**:
            - `audio`: Audio files
            - `video`: Video content

        model_name : CreateAsyncEmbeddingRequestModelName
            The model you wish to use. Value: `"marengo3.0"`.

        audio : typing.Optional[AudioInputRequest]

        video : typing.Optional[VideoInputRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TasksCreateResponse
            An embedding task has successfully been created.

        Examples
        --------
        from twelvelabs import (
            AudioInputRequest,
            AudioSegmentation,
            AudioSegmentationFixed,
            MediaSource,
            TwelveLabs,
        )

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.embed.v_2.tasks.create(
            input_type="audio",
            model_name="marengo3.0",
            audio=AudioInputRequest(
                media_source=MediaSource(
                    url="https://user-bucket.com/audio/long-audio.wav",
                ),
                start_sec=0.0,
                end_sec=3600.0,
                segmentation=AudioSegmentation(
                    strategy="fixed",
                    fixed=AudioSegmentationFixed(
                        duration_sec=6,
                    ),
                ),
                embedding_option=["audio", "transcription"],
                embedding_scope=["clip", "asset"],
            ),
        )
        """
        _response = self._raw_client.create(
            input_type=input_type, model_name=model_name, audio=audio, video=video, request_options=request_options
        )
        return _response.data

    def retrieve(
        self, task_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> EmbeddingTaskResponse:
        """
        This method retrieves the status and the results of an async embedding task.

        **Task statuses**:
        - `processing`: The platform is creating the embeddings.
        - `ready`: Processing is complete. Embeddings are available in the response.
        - `failed`: The task failed. Embeddings were not created.

        Invoke this method repeatedly until the `status` field is `ready`. When `status` is `ready`, use the embeddings from the response.

        Parameters
        ----------
        task_id : str
            The unique identifier of the embedding task.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmbeddingTaskResponse
            Task status and results retrieved successfully

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.embed.v_2.tasks.retrieve(
            task_id="64f8d2c7e4a1b37f8a9c5d12",
        )
        """
        _response = self._raw_client.retrieve(task_id, request_options=request_options)
        return _response.data


class AsyncTasksClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTasksClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTasksClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTasksClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        started_at: typing.Optional[str] = None,
        ended_at: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        page: typing.Optional[int] = None,
        page_limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[MediaEmbeddingTask]:
        """
        This method returns a list of the async embedding tasks in your account. The platform returns your async embedding tasks sorted by creation date, with the newest at the top of the list.

        Parameters
        ----------
        started_at : typing.Optional[str]
            Retrieve the embedding tasks that were created after the given date and time, expressed in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ").

        ended_at : typing.Optional[str]
            Retrieve the embedding tasks that were created before the given date and time, expressed in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ").

        status : typing.Optional[str]
            Filter the embedding tasks by their current status.

            **Values**: `processing`, `ready`, or `failed`.

        page : typing.Optional[int]
            A number that identifies the page to retrieve.

            **Default**: `1`.

        page_limit : typing.Optional[int]
            The number of items to return on each page.

            **Default**: `10`.
            **Max**: `50`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[MediaEmbeddingTask]
            A list of async embedding tasks has successfully been retrieved.

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            response = await client.embed.v_2.tasks.list(
                started_at="2024-03-01T00:00:00Z",
                ended_at="2024-03-01T00:00:00Z",
                status="processing",
                page=1,
                page_limit=10,
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.list(
            started_at=started_at,
            ended_at=ended_at,
            status=status,
            page=page,
            page_limit=page_limit,
            request_options=request_options,
        )

    async def create(
        self,
        *,
        input_type: CreateAsyncEmbeddingRequestInputType,
        model_name: CreateAsyncEmbeddingRequestModelName,
        audio: typing.Optional[AudioInputRequest] = OMIT,
        video: typing.Optional[VideoInputRequest] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TasksCreateResponse:
        """
        This endpoint creates embeddings for audio and video content asynchronously.

        **When to use this endpoint**:
        - Process audio or video files longer than 10 minutes
        - Process files up to 4 hours in duration

        <Accordion title="Input requirements">
          **Video**:
          - Minimum duration: 4 seconds
          - Maximum duration: 4 hours
          - Maximum file size: 4 GB
          - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
          - Resolution: 360x360 to 5184x2160 pixels
          - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1

          **Audio**:
          - Minimum duration: 4 seconds
          - Maximum duration: 4 hours
          - Maximum file size: 2 GB
          - Formats: WAV (uncompressed), MP3 (lossy), FLAC (lossless)
        </Accordion>

          Creating embeddings asynchronously requires three steps:

          1. Create a task using this endpoint. The platform returns a task ID.
          2. Poll for the status of the task using the [`GET`](/v1.3/api-reference/create-embeddings-v2/retrieve-embeddings) method of the `/embed-v2/tasks/{task_id}` endpoint. Wait until the status is `ready`.
          3. Retrieve the embeddings from the response when the status is `ready` using the [`GET`](/v1.3/api-reference/create-embeddings-v2/retrieve-embeddings) method of the `/embed-v2/tasks/{task_id}` endpoint.

          <Note title="Note">
          This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
          </Note>

        Parameters
        ----------
        input_type : CreateAsyncEmbeddingRequestInputType
            The type of content for the embeddings.

            **Values**:
            - `audio`: Audio files
            - `video`: Video content

        model_name : CreateAsyncEmbeddingRequestModelName
            The model you wish to use. Value: `"marengo3.0"`.

        audio : typing.Optional[AudioInputRequest]

        video : typing.Optional[VideoInputRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TasksCreateResponse
            An embedding task has successfully been created.

        Examples
        --------
        import asyncio

        from twelvelabs import (
            AsyncTwelveLabs,
            AudioInputRequest,
            AudioSegmentation,
            AudioSegmentationFixed,
            MediaSource,
        )

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.embed.v_2.tasks.create(
                input_type="audio",
                model_name="marengo3.0",
                audio=AudioInputRequest(
                    media_source=MediaSource(
                        url="https://user-bucket.com/audio/long-audio.wav",
                    ),
                    start_sec=0.0,
                    end_sec=3600.0,
                    segmentation=AudioSegmentation(
                        strategy="fixed",
                        fixed=AudioSegmentationFixed(
                            duration_sec=6,
                        ),
                    ),
                    embedding_option=["audio", "transcription"],
                    embedding_scope=["clip", "asset"],
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            input_type=input_type, model_name=model_name, audio=audio, video=video, request_options=request_options
        )
        return _response.data

    async def retrieve(
        self, task_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> EmbeddingTaskResponse:
        """
        This method retrieves the status and the results of an async embedding task.

        **Task statuses**:
        - `processing`: The platform is creating the embeddings.
        - `ready`: Processing is complete. Embeddings are available in the response.
        - `failed`: The task failed. Embeddings were not created.

        Invoke this method repeatedly until the `status` field is `ready`. When `status` is `ready`, use the embeddings from the response.

        Parameters
        ----------
        task_id : str
            The unique identifier of the embedding task.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmbeddingTaskResponse
            Task status and results retrieved successfully

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.embed.v_2.tasks.retrieve(
                task_id="64f8d2c7e4a1b37f8a9c5d12",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.retrieve(task_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ....core.serialization import FieldMetadata
from .tasks_status_response_video_embedding import TasksStatusResponseVideoEmbedding


class TasksStatusResponse(UniversalBaseModel):
    id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="_id")] = pydantic.Field(default=None)
    """
    The unique identifier of the video embedding task.
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    A string indicating the status of the video indexing task. It can take one of the following values: `processing`, `ready` or `failed`.
    """

    model_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the video understanding model the platform used to create the embedding.
    """

    video_embedding: typing.Optional[TasksStatusResponseVideoEmbedding] = pydantic.Field(default=None)
    """
    An object containing the metadata associated with the embedding.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.http_response import AsyncHttpResponse, HttpResponse
from ...core.pydantic_utilities import parse_obj_as
from ...core.request_options import RequestOptions
from ...core.serialization import convert_and_respect_annotation_metadata
from ...errors.bad_request_error import BadRequestError
from ...errors.internal_server_error import InternalServerError
from ...errors.too_many_requests_error import TooManyRequestsError
from ...types.audio_input_request import AudioInputRequest
from ...types.embedding_success_response import EmbeddingSuccessResponse
from ...types.image_input_request import ImageInputRequest
from ...types.multi_input_request import MultiInputRequest
from ...types.text_image_input_request import TextImageInputRequest
from ...types.text_input_request import TextInputRequest
from ...types.video_input_request import VideoInputRequest
from .types.create_embeddings_request_input_type import CreateEmbeddingsRequestInputType
from .types.create_embeddings_request_model_name import CreateEmbeddingsRequestModelName

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawV2Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self,
        *,
        input_type: CreateEmbeddingsRequestInputType,
        model_name: CreateEmbeddingsRequestModelName,
        text: typing.Optional[TextInputRequest] = OMIT,
        image: typing.Optional[ImageInputRequest] = OMIT,
        text_image: typing.Optional[TextImageInputRequest] = OMIT,
        audio: typing.Optional[AudioInputRequest] = OMIT,
        video: typing.Optional[VideoInputRequest] = OMIT,
        multi_input: typing.Optional[MultiInputRequest] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[EmbeddingSuccessResponse]:
        """
        This endpoint synchronously creates embeddings for multimodal content and returns the results immediately in the response.

        **When to use this endpoint**:
        - Create embeddings for text, images, audio, or video content
        - Retrieve immediate results without waiting for background processing
        - Process audio or video content up to 10 minutes in duration

        **Do not use this endpoint for**:
        - Audio or video content longer than 10 minutes. Use the [`POST`](/v1.3/api-reference/create-embeddings-v2/create-async-embedding-task) method of the `/embed-v2/tasks` endpoint instead.

        <Accordion title="Input requirements">
          **Text**:
          - Maximum length: 500 tokens

          **Images**:
          - Formats: JPEG, PNG
          - Minimum size: 128x128 pixels
          - Maximum file size: 5 MB

          **Audio and video**:
          - Maximum duration: 10 minutes
          - Maximum file size for base64 encoded strings: 36 MB
          - Audio formats: WAV (uncompressed), MP3 (lossy), FLAC (lossless)
          - Video formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
          - Video resolution: 360x360 to 5184x2160 pixels
          - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1
        </Accordion>

        <Note title="Note">
        This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        input_type : CreateEmbeddingsRequestInputType
            The type of content for the embeddings.


            **Values**:
            - `audio`: Creates embeddings for an audio file
            - `video`: Creates embeddings for a video file
            - `image`: Creates embeddings for an image file
            - `text`: Creates embeddings for text input
            - `text_image`: Creates embeddings for text and an image
            - `multi_input`: Creates a single embedding from up to 10 images. You can optionally include text to provide context. To reference specific images in your text, use placeholders in the following format: `<@name>`, where `name` matches the `name` field of a media source

        model_name : CreateEmbeddingsRequestModelName
            The video understanding model to use. Value: "marengo3.0".

        text : typing.Optional[TextInputRequest]

        image : typing.Optional[ImageInputRequest]

        text_image : typing.Optional[TextImageInputRequest]

        audio : typing.Optional[AudioInputRequest]

        video : typing.Optional[VideoInputRequest]

        multi_input : typing.Optional[MultiInputRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EmbeddingSuccessResponse]
            Successful request; normal operation
        """
        _response = self._client_wrapper.httpx_client.request(
            "embed-v2",
            method="POST",
            json={
                "input_type": input_type,
                "model_name": model_name,
                "text": convert_and_respect_annotation_metadata(
                    object_=text, annotation=TextInputRequest, direction="write"
                ),
                "image": convert_and_respect_annotation_metadata(
                    object_=image, annotation=ImageInputRequest, direction="write"
                ),
                "text_image": convert_and_respect_annotation_metadata(
                    object_=text_image, annotation=TextImageInputRequest, direction="write"
                ),
                "audio": convert_and_respect_annotation_metadata(
                    object_=audio, annotation=AudioInputRequest, direction="write"
                ),
                "video": convert_and_respect_annotation_metadata(
                    object_=video, annotation=VideoInputRequest, direction="write"
                ),
                "multi_input": convert_and_respect_annotation_metadata(
                    object_=multi_input, annotation=MultiInputRequest, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EmbeddingSuccessResponse,
                    parse_obj_as(
                        type_=EmbeddingSuccessResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawV2Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self,
        *,
        input_type: CreateEmbeddingsRequestInputType,
        model_name: CreateEmbeddingsRequestModelName,
        text: typing.Optional[TextInputRequest] = OMIT,
        image: typing.Optional[ImageInputRequest] = OMIT,
        text_image: typing.Optional[TextImageInputRequest] = OMIT,
        audio: typing.Optional[AudioInputRequest] = OMIT,
        video: typing.Optional[VideoInputRequest] = OMIT,
        multi_input: typing.Optional[MultiInputRequest] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[EmbeddingSuccessResponse]:
        """
        This endpoint synchronously creates embeddings for multimodal content and returns the results immediately in the response.

        **When to use this endpoint**:
        - Create embeddings for text, images, audio, or video content
        - Retrieve immediate results without waiting for background processing
        - Process audio or video content up to 10 minutes in duration

        **Do not use this endpoint for**:
        - Audio or video content longer than 10 minutes. Use the [`POST`](/v1.3/api-reference/create-embeddings-v2/create-async-embedding-task) method of the `/embed-v2/tasks` endpoint instead.

        <Accordion title="Input requirements">
          **Text**:
          - Maximum length: 500 tokens

          **Images**:
          - Formats: JPEG, PNG
          - Minimum size: 128x128 pixels
          - Maximum file size: 5 MB

          **Audio and video**:
          - Maximum duration: 10 minutes
          - Maximum file size for base64 encoded strings: 36 MB
          - Audio formats: WAV (uncompressed), MP3 (lossy), FLAC (lossless)
          - Video formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
          - Video resolution: 360x360 to 5184x2160 pixels
          - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1
        </Accordion>

        <Note title="Note">
        This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        input_type : CreateEmbeddingsRequestInputType
            The type of content for the embeddings.


            **Values**:
            - `audio`: Creates embeddings for an audio file
            - `video`: Creates embeddings for a video file
            - `image`: Creates embeddings for an image file
            - `text`: Creates embeddings for text input
            - `text_image`: Creates embeddings for text and an image
            - `multi_input`: Creates a single embedding from up to 10 images. You can optionally include text to provide context. To reference specific images in your text, use placeholders in the following format: `<@name>`, where `name` matches the `name` field of a media source

        model_name : CreateEmbeddingsRequestModelName
            The video understanding model to use. Value: "marengo3.0".

        text : typing.Optional[TextInputRequest]

        image : typing.Optional[ImageInputRequest]

        text_image : typing.Optional[TextImageInputRequest]

        audio : typing.Optional[AudioInputRequest]

        video : typing.Optional[VideoInputRequest]

        multi_input : typing.Optional[MultiInputRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EmbeddingSuccessResponse]
            Successful request; normal operation
        """
        _response = await self._client_wrapper.httpx_client.request(
            "embed-v2",
            method="POST",
            json={
                "input_type": input_type,
                "model_name": model_name,
                "text": convert_and_respect_annotation_metadata(
                    object_=text, annotation=TextInputRequest, direction="write"
                ),
                "image": convert_and_respect_annotation_metadata(
                    object_=image, annotation=ImageInputRequest, direction="write"
                ),
                "text_image": convert_and_respect_annotation_metadata(
                    object_=text_image, annotation=TextImageInputRequest, direction="write"
                ),
                "audio": convert_and_respect_annotation_metadata(
                    object_=audio, annotation=AudioInputRequest, direction="write"
                ),
                "video": convert_and_respect_annotation_metadata(
                    object_=video, annotation=VideoInputRequest, direction="write"
                ),
                "multi_input": convert_and_respect_annotation_metadata(
                    object_=multi_input, annotation=MultiInputRequest, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EmbeddingSuccessResponse,
                    parse_obj_as(
                        type_=EmbeddingSuccessResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    SearchCreateRequestGroupBy,
    SearchCreateRequestOperator,
    SearchCreateRequestQueryMediaType,
    SearchCreateRequestSearchOptionsItem,
    SearchCreateRequestTranscriptionOptionsItem,
    SearchRetrieveResponse,
    SearchRetrieveResponsePageInfo,
)

__all__ = [
    "SearchCreateRequestGroupBy",
    "SearchCreateRequestOperator",
    "SearchCreateRequestQueryMediaType",
    "SearchCreateRequestSearchOptionsItem",
    "SearchCreateRequestTranscriptionOptionsItem",
    "SearchRetrieveResponse",
    "SearchRetrieveResponsePageInfo",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .expires_at import ExpiresAt
from .presigned_url_chunk import PresignedUrlChunk


class RequestAdditionalPresignedUrLsResponse(UniversalBaseModel):
    upload_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique identifier of the upload session associated with these URLs.
    """

    start_index: typing.Optional[int] = pydantic.Field(default=None)
    """
    The index of the first chunk number in this set of URLs. Matches the start value from your request.
    """

    count: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of new URLs created. Matches the count value from your request.
    """

    upload_urls: typing.Optional[typing.List[PresignedUrlChunk]] = pydantic.Field(default=None)
    """
    An array of additional presigned URLs for uploading chunks.
    """

    generated_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The date and time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when these URLs were created. URLs remain valid for 1 hour from this time.
    """

    expires_at: typing.Optional[ExpiresAt] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SummarizeChapterResultChaptersItem(UniversalBaseModel):
    """
    An object that contains details about a chapter. Each chapter has a unique number, start time, end time, title, and summary.
    """

    chapter_number: typing.Optional[int] = pydantic.Field(default=None)
    """
    Represents the sequence number of the chapter. Note that this field starts at 0. Ensure to interpret it accordingly in your application.
    """

    start: typing.Optional[int] = pydantic.Field(default=None)
    """
    The starting time of the chapter, measured in seconds from the beginning of the video.
    """

    end: typing.Optional[int] = pydantic.Field(default=None)
    """
    The ending time of the chapter, measured in seconds from the beginning of the video.
    """

    start_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    The starting time of the chapter, measured in seconds from the beginning of the video.
    """

    end_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    The ending time of the chapter, measured in seconds from the beginning of the video.
    """

    chapter_title: typing.Optional[str] = pydantic.Field(default=None)
    """
    The title of the chapter.
    """

    chapter_summary: typing.Optional[str] = pydantic.Field(default=None)
    """
    A brief summary describing the content of the chapter.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .indexed_asset_status import IndexedAssetStatus
from .indexed_asset_system_metadata import IndexedAssetSystemMetadata


class IndexedAsset(UniversalBaseModel):
    """
    An indexed asset object that contains information about the indexed asset, including its indexing status.
    """

    id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="_id")] = pydantic.Field(default=None)
    """
    A string representing the unique identifier of your indexed asset.
    """

    created_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    A string indicating the date and time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), that the indexing task was created.
    """

    updated_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    A string indicating the date and time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), that the indexing task was last updated. The platform updates this field every time the indexing task transitions to a different state.
    """

    indexed_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    A string indicating the date and time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), that the indexing task has been completed.
    """

    status: typing.Optional[IndexedAssetStatus] = pydantic.Field(default=None)
    """
    The status of the indexing task.
    """

    system_metadata: typing.Optional[IndexedAssetSystemMetadata] = pydantic.Field(default=None)
    """
    System-generated metadata about the indexed asset.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .hls_object import HlsObject
from .indexed_asset import IndexedAsset
from .indexed_asset_detailed_embedding import IndexedAssetDetailedEmbedding
from .transcription_data import TranscriptionData


class IndexedAssetDetailed(IndexedAsset):
    user_metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    User-generated metadata about the indexed asset.
    """

    hls: typing.Optional[HlsObject] = None
    embedding: typing.Optional[IndexedAssetDetailedEmbedding] = pydantic.Field(default=None)
    """
    Contains the embedding and the associated information. The platform returns this field when the `embedding_option` parameter is specified in the request.
    """

    transcription: typing.Optional[TranscriptionData] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AudioSegmentationFixed(UniversalBaseModel):
    """
    Configuration for fixed segmentation.

    This object is required when the `strategy` field is `fixed`.
    """

    duration_sec: int = pydantic.Field()
    """
    The duration in seconds for each segment. The platform divides the audio into segments of this exact length. The final segment may be shorter if the audio duration is not evenly divisible.
    
     **Example**: With `duration_sec: 5`, a 12-second audio file produces segments: [0-5s], [5-10s], [10-12s].
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import IndexesCreateRequestModelsItem, IndexesCreateResponse, IndexesListResponse
from . import indexed_assets, videos
from .indexed_assets import (
    IndexedAssetsCreateResponse,
    IndexedAssetsListRequestStatusItem,
    IndexedAssetsListRequestUserMetadataValue,
    IndexedAssetsListResponse,
    IndexedAssetsRetrieveRequestEmbeddingOptionItem,
)
from .videos import (
    VideosListRequestUserMetadataValue,
    VideosListResponse,
    VideosRetrieveRequestEmbeddingOptionItem,
    VideosRetrieveResponse,
    VideosRetrieveResponseEmbedding,
    VideosRetrieveResponseEmbeddingVideoEmbedding,
    VideosRetrieveResponseSystemMetadata,
)

__all__ = [
    "IndexedAssetsCreateResponse",
    "IndexedAssetsListRequestStatusItem",
    "IndexedAssetsListRequestUserMetadataValue",
    "IndexedAssetsListResponse",
    "IndexedAssetsRetrieveRequestEmbeddingOptionItem",
    "IndexesCreateRequestModelsItem",
    "IndexesCreateResponse",
    "IndexesListResponse",
    "VideosListRequestUserMetadataValue",
    "VideosListResponse",
    "VideosRetrieveRequestEmbeddingOptionItem",
    "VideosRetrieveResponse",
    "VideosRetrieveResponseEmbedding",
    "VideosRetrieveResponseEmbeddingVideoEmbedding",
    "VideosRetrieveResponseSystemMetadata",
    "indexed_assets",
    "videos",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ....types.analyze_task_response import AnalyzeTaskResponse
from ....types.page_info import PageInfo


class TasksListResponse(UniversalBaseModel):
    data: typing.List[AnalyzeTaskResponse] = pydantic.Field()
    """
    An array that contains up to `page_limit` analysis tasks.
    """

    page_info: PageInfo

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .summarize_highlight_result_highlights_item import SummarizeHighlightResultHighlightsItem
from .summarize_highlight_result_summarize_type import SummarizeHighlightResultSummarizeType
from .token_usage import TokenUsage


class SummarizeHighlightResult(UniversalBaseModel):
    """
    An object that represents the response from a summarize highlight operation.
    """

    summarize_type: SummarizeHighlightResultSummarizeType = pydantic.Field()
    """
    The type of summarize response.
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier of the response.
    """

    highlights: typing.Optional[typing.List[SummarizeHighlightResultHighlightsItem]] = pydantic.Field(default=None)
    """
    An array that contains the highlights.
    """

    usage: typing.Optional[TokenUsage] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class IndexModelsItem(UniversalBaseModel):
    model_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    A string representing the name of the model.
    """

    model_options: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    An array of strings that contains the [model options](/v1.3/docs/concepts/modalities#model-options) enabled for this index.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    TasksCreateRequestVideoEmbeddingScopeItem,
    TasksCreateResponse,
    TasksListResponse,
    TasksListResponsePageInfo,
    TasksRetrieveRequestEmbeddingOptionItem,
    TasksRetrieveResponse,
    TasksRetrieveResponseVideoEmbedding,
    TasksStatusResponse,
    TasksStatusResponseVideoEmbedding,
)

__all__ = [
    "TasksCreateRequestVideoEmbeddingScopeItem",
    "TasksCreateResponse",
    "TasksListResponse",
    "TasksListResponsePageInfo",
    "TasksRetrieveRequestEmbeddingOptionItem",
    "TasksRetrieveResponse",
    "TasksRetrieveResponseVideoEmbedding",
    "TasksStatusResponse",
    "TasksStatusResponseVideoEmbedding",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SummarizeHighlightResultHighlightsItem(UniversalBaseModel):
    """
    An object that provides a brief snapshot of a specific part of the video.
    """

    start: typing.Optional[int] = pydantic.Field(default=None)
    """
    The starting time of the highlight, measured in seconds from the beginning of the video.
    """

    end: typing.Optional[int] = pydantic.Field(default=None)
    """
    The ending time of the highlight, measured in seconds from the beginning of the video.
    """

    start_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    The starting time of the highlight, measured in seconds from the beginning of the video.
    """

    end_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    The ending time of the highlight, measured in seconds from the beginning of the video.
    """

    highlight: typing.Optional[str] = pydantic.Field(default=None)
    """
    The tile of the highlight.
    """

    highlight_summary: typing.Optional[str] = pydantic.Field(default=None)
    """
    A brief description that captures the essence of this part of the video.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



import typing
import os

from .base_client import BaseClient, AsyncBaseClient
from .wrapper.search_client_wrapper import SearchClientWrapper, AsyncSearchClientWrapper
from .wrapper.task_client_wrapper import TaskClientWrapper, AsyncTaskClientWrapper
from .wrapper.embed_client_wrapper import EmbedClientWrapper, AsyncEmbedClientWrapper
from .wrapper.index_client_wrapper import (
    IndexesClientWrapper,
    AsyncIndexesClientWrapper,
)
from .wrapper.multipart_upload_client_wrapper import MultipartUploadClientWrapper, AsyncMultipartUploadClientWrapper

OMIT = typing.cast(typing.Any, ...)


class TwelveLabs(BaseClient):
    def __init__(
        self,
        *,
        api_key: typing.Optional[str] = None,
        **kwargs,
    ):
        """
        Initialize the TwelveLabs client.

        Parameters
        ----------
        api_key : str, optional
            The API key for authentication with TwelveLabs API.
            If not provided, the TWELVE_LABS_API_KEY environment variable will be used.
        **kwargs : dict
            Additional parameters to pass to the BaseClient
        """
        if api_key:
            kwargs["api_key"] = api_key

        if os.getenv("TWELVELABS_BASE_URL"):
            kwargs["base_url"] = os.getenv("TWELVELABS_BASE_URL")

        super().__init__(**kwargs)

        self.search = SearchClientWrapper(client_wrapper=self._client_wrapper)
        self.tasks = TaskClientWrapper(client_wrapper=self._client_wrapper)
        self.embed = EmbedClientWrapper(client_wrapper=self._client_wrapper)
        self.indexes = IndexesClientWrapper(client_wrapper=self._client_wrapper)
        self.multipart_upload = MultipartUploadClientWrapper(client_wrapper=self._client_wrapper)

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        pass


class AsyncTwelveLabs(AsyncBaseClient):
    def __init__(
        self,
        *,
        api_key: typing.Optional[str] = None,
        **kwargs,
    ):
        """
        Initialize the AsyncTwelveLabs client.

        Parameters
        ----------
        api_key : str, optional
            The API key for authentication with TwelveLabs API.
            If not provided, the TWELVE_LABS_API_KEY environment variable will be used.
        **kwargs : dict
            Additional parameters to pass to the AsyncBaseClient
        """
        if api_key:
            kwargs["api_key"] = api_key

        if os.getenv("TWELVELABS_BASE_URL"):
            kwargs["base_url"] = os.getenv("TWELVELABS_BASE_URL")

        super().__init__(**kwargs)

        self.search = AsyncSearchClientWrapper(client_wrapper=self._client_wrapper)
        self.tasks = AsyncTaskClientWrapper(client_wrapper=self._client_wrapper)
        self.embed = AsyncEmbedClientWrapper(client_wrapper=self._client_wrapper)
        self.indexes = AsyncIndexesClientWrapper(client_wrapper=self._client_wrapper)
        self.multipart_upload = AsyncMultipartUploadClientWrapper(client_wrapper=self._client_wrapper)

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc_value, traceback):
        pass



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import AssetsCreateRequestMethod, AssetsListRequestAssetTypesItem, AssetsListResponse

__all__ = ["AssetsCreateRequestMethod", "AssetsListRequestAssetTypesItem", "AssetsListResponse"]



# This file was auto-generated by Fern from our API Definition.

import typing

VideosRetrieveRequestEmbeddingOptionItem = typing.Union[
    typing.Literal["visual", "audio", "transcription", "visual-text"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import contextlib
import json
import typing
from json.decoder import JSONDecodeError

from .core.api_error import ApiError
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.http_response import AsyncHttpResponse, HttpResponse
from .core.pydantic_utilities import parse_obj_as
from .core.request_options import RequestOptions
from .core.serialization import convert_and_respect_annotation_metadata
from .errors.bad_request_error import BadRequestError
from .errors.too_many_requests_error import TooManyRequestsError
from .types.analyze_max_tokens import AnalyzeMaxTokens
from .types.analyze_temperature import AnalyzeTemperature
from .types.analyze_text_prompt import AnalyzeTextPrompt
from .types.non_stream_analyze_response import NonStreamAnalyzeResponse
from .types.response_format import ResponseFormat
from .types.stream_analyze_response import StreamAnalyzeResponse
from .types.video_context import VideoContext

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawBaseClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    @contextlib.contextmanager
    def analyze_stream(
        self,
        *,
        prompt: AnalyzeTextPrompt,
        video_id: typing.Optional[str] = OMIT,
        video: typing.Optional[VideoContext] = OMIT,
        temperature: typing.Optional[AnalyzeTemperature] = OMIT,
        response_format: typing.Optional[ResponseFormat] = OMIT,
        max_tokens: typing.Optional[AnalyzeMaxTokens] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[HttpResponse[typing.Iterator[StreamAnalyzeResponse]]]:
        """
        This method synchronously analyzes your videos and generates fully customizable text based on your prompts.

        <Accordion title="Input requirements">
        - Minimum duration: 4 seconds
        - Maximum duration: 1 hour
        - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
        - Resolution: 360x360 to 5184x2160 pixels
        - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1.
        </Accordion>

        **When to use this method**:
        - Analyze videos up to 1 hour
        - Retrieve immediate results without waiting for asynchronous processing
        - Stream text fragments in real-time for immediate processing and feedback

        **Do not use this method for**:
        - Videos longer than 1 hour. Use the [`POST`](/v1.3/api-reference/analyze-videos/create-async-analysis-task) method of the `/analyze/tasks` endpoint instead.

        <Note title="Notes">
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        prompt : AnalyzeTextPrompt

        video_id : typing.Optional[str]
            The unique identifier of the video to analyze.

            <Info> This parameter will be deprecated and removed in a future version. Use the [`video`](/v1.3/api-reference/analyze-videos/sync-analysis#request.body.video) parameter instead.</Info>

        video : typing.Optional[VideoContext]

        temperature : typing.Optional[AnalyzeTemperature]

        response_format : typing.Optional[ResponseFormat]

        max_tokens : typing.Optional[AnalyzeMaxTokens]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.Iterator[HttpResponse[typing.Iterator[StreamAnalyzeResponse]]]

        """
        with self._client_wrapper.httpx_client.stream(
            "analyze",
            method="POST",
            json={
                "video_id": video_id,
                "video": convert_and_respect_annotation_metadata(
                    object_=video, annotation=VideoContext, direction="write"
                ),
                "prompt": prompt,
                "temperature": temperature,
                "response_format": convert_and_respect_annotation_metadata(
                    object_=response_format, annotation=ResponseFormat, direction="write"
                ),
                "max_tokens": max_tokens,
                "stream": True,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:

            def _stream() -> HttpResponse[typing.Iterator[StreamAnalyzeResponse]]:
                try:
                    if 200 <= _response.status_code < 300:

                        def _iter():
                            for _text in _response.iter_lines():
                                try:
                                    if len(_text) == 0:
                                        continue
                                    yield typing.cast(
                                        StreamAnalyzeResponse,
                                        parse_obj_as(
                                            type_=StreamAnalyzeResponse,  # type: ignore
                                            object_=json.loads(_text),
                                        ),
                                    )
                                except Exception:
                                    pass
                            return

                        return HttpResponse(response=_response, data=_iter())
                    _response.read()
                    if _response.status_code == 400:
                        raise BadRequestError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                typing.Optional[typing.Any],
                                parse_obj_as(
                                    type_=typing.Optional[typing.Any],  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    if _response.status_code == 429:
                        raise TooManyRequestsError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                typing.Optional[typing.Any],
                                parse_obj_as(
                                    type_=typing.Optional[typing.Any],  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield _stream()

    def analyze(
        self,
        *,
        prompt: AnalyzeTextPrompt,
        video_id: typing.Optional[str] = OMIT,
        video: typing.Optional[VideoContext] = OMIT,
        temperature: typing.Optional[AnalyzeTemperature] = OMIT,
        response_format: typing.Optional[ResponseFormat] = OMIT,
        max_tokens: typing.Optional[AnalyzeMaxTokens] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[NonStreamAnalyzeResponse]:
        """
        This method synchronously analyzes your videos and generates fully customizable text based on your prompts.

        <Accordion title="Input requirements">
        - Minimum duration: 4 seconds
        - Maximum duration: 1 hour
        - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
        - Resolution: 360x360 to 5184x2160 pixels
        - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1.
        </Accordion>

        **When to use this method**:
        - Analyze videos up to 1 hour
        - Retrieve immediate results without waiting for asynchronous processing
        - Stream text fragments in real-time for immediate processing and feedback

        **Do not use this method for**:
        - Videos longer than 1 hour. Use the [`POST`](/v1.3/api-reference/analyze-videos/create-async-analysis-task) method of the `/analyze/tasks` endpoint instead.

        <Note title="Notes">
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        prompt : AnalyzeTextPrompt

        video_id : typing.Optional[str]
            The unique identifier of the video to analyze.

            <Info> This parameter will be deprecated and removed in a future version. Use the [`video`](/v1.3/api-reference/analyze-videos/sync-analysis#request.body.video) parameter instead.</Info>

        video : typing.Optional[VideoContext]

        temperature : typing.Optional[AnalyzeTemperature]

        response_format : typing.Optional[ResponseFormat]

        max_tokens : typing.Optional[AnalyzeMaxTokens]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[NonStreamAnalyzeResponse]

        """
        _response = self._client_wrapper.httpx_client.request(
            "analyze",
            method="POST",
            json={
                "video_id": video_id,
                "video": convert_and_respect_annotation_metadata(
                    object_=video, annotation=VideoContext, direction="write"
                ),
                "prompt": prompt,
                "temperature": temperature,
                "response_format": convert_and_respect_annotation_metadata(
                    object_=response_format, annotation=ResponseFormat, direction="write"
                ),
                "max_tokens": max_tokens,
                "stream": False,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    NonStreamAnalyzeResponse,
                    parse_obj_as(
                        type_=NonStreamAnalyzeResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawBaseClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    @contextlib.asynccontextmanager
    async def analyze_stream(
        self,
        *,
        prompt: AnalyzeTextPrompt,
        video_id: typing.Optional[str] = OMIT,
        video: typing.Optional[VideoContext] = OMIT,
        temperature: typing.Optional[AnalyzeTemperature] = OMIT,
        response_format: typing.Optional[ResponseFormat] = OMIT,
        max_tokens: typing.Optional[AnalyzeMaxTokens] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[StreamAnalyzeResponse]]]:
        """
        This method synchronously analyzes your videos and generates fully customizable text based on your prompts.

        <Accordion title="Input requirements">
        - Minimum duration: 4 seconds
        - Maximum duration: 1 hour
        - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
        - Resolution: 360x360 to 5184x2160 pixels
        - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1.
        </Accordion>

        **When to use this method**:
        - Analyze videos up to 1 hour
        - Retrieve immediate results without waiting for asynchronous processing
        - Stream text fragments in real-time for immediate processing and feedback

        **Do not use this method for**:
        - Videos longer than 1 hour. Use the [`POST`](/v1.3/api-reference/analyze-videos/create-async-analysis-task) method of the `/analyze/tasks` endpoint instead.

        <Note title="Notes">
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        prompt : AnalyzeTextPrompt

        video_id : typing.Optional[str]
            The unique identifier of the video to analyze.

            <Info> This parameter will be deprecated and removed in a future version. Use the [`video`](/v1.3/api-reference/analyze-videos/sync-analysis#request.body.video) parameter instead.</Info>

        video : typing.Optional[VideoContext]

        temperature : typing.Optional[AnalyzeTemperature]

        response_format : typing.Optional[ResponseFormat]

        max_tokens : typing.Optional[AnalyzeMaxTokens]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[StreamAnalyzeResponse]]]

        """
        async with self._client_wrapper.httpx_client.stream(
            "analyze",
            method="POST",
            json={
                "video_id": video_id,
                "video": convert_and_respect_annotation_metadata(
                    object_=video, annotation=VideoContext, direction="write"
                ),
                "prompt": prompt,
                "temperature": temperature,
                "response_format": convert_and_respect_annotation_metadata(
                    object_=response_format, annotation=ResponseFormat, direction="write"
                ),
                "max_tokens": max_tokens,
                "stream": True,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:

            async def _stream() -> AsyncHttpResponse[typing.AsyncIterator[StreamAnalyzeResponse]]:
                try:
                    if 200 <= _response.status_code < 300:

                        async def _iter():
                            async for _text in _response.aiter_lines():
                                try:
                                    if len(_text) == 0:
                                        continue
                                    yield typing.cast(
                                        StreamAnalyzeResponse,
                                        parse_obj_as(
                                            type_=StreamAnalyzeResponse,  # type: ignore
                                            object_=json.loads(_text),
                                        ),
                                    )
                                except Exception:
                                    pass
                            return

                        return AsyncHttpResponse(response=_response, data=_iter())
                    await _response.aread()
                    if _response.status_code == 400:
                        raise BadRequestError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                typing.Optional[typing.Any],
                                parse_obj_as(
                                    type_=typing.Optional[typing.Any],  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    if _response.status_code == 429:
                        raise TooManyRequestsError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                typing.Optional[typing.Any],
                                parse_obj_as(
                                    type_=typing.Optional[typing.Any],  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield await _stream()

    async def analyze(
        self,
        *,
        prompt: AnalyzeTextPrompt,
        video_id: typing.Optional[str] = OMIT,
        video: typing.Optional[VideoContext] = OMIT,
        temperature: typing.Optional[AnalyzeTemperature] = OMIT,
        response_format: typing.Optional[ResponseFormat] = OMIT,
        max_tokens: typing.Optional[AnalyzeMaxTokens] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[NonStreamAnalyzeResponse]:
        """
        This method synchronously analyzes your videos and generates fully customizable text based on your prompts.

        <Accordion title="Input requirements">
        - Minimum duration: 4 seconds
        - Maximum duration: 1 hour
        - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
        - Resolution: 360x360 to 5184x2160 pixels
        - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1.
        </Accordion>

        **When to use this method**:
        - Analyze videos up to 1 hour
        - Retrieve immediate results without waiting for asynchronous processing
        - Stream text fragments in real-time for immediate processing and feedback

        **Do not use this method for**:
        - Videos longer than 1 hour. Use the [`POST`](/v1.3/api-reference/analyze-videos/create-async-analysis-task) method of the `/analyze/tasks` endpoint instead.

        <Note title="Notes">
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        prompt : AnalyzeTextPrompt

        video_id : typing.Optional[str]
            The unique identifier of the video to analyze.

            <Info> This parameter will be deprecated and removed in a future version. Use the [`video`](/v1.3/api-reference/analyze-videos/sync-analysis#request.body.video) parameter instead.</Info>

        video : typing.Optional[VideoContext]

        temperature : typing.Optional[AnalyzeTemperature]

        response_format : typing.Optional[ResponseFormat]

        max_tokens : typing.Optional[AnalyzeMaxTokens]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[NonStreamAnalyzeResponse]

        """
        _response = await self._client_wrapper.httpx_client.request(
            "analyze",
            method="POST",
            json={
                "video_id": video_id,
                "video": convert_and_respect_annotation_metadata(
                    object_=video, annotation=VideoContext, direction="write"
                ),
                "prompt": prompt,
                "temperature": temperature,
                "response_format": convert_and_respect_annotation_metadata(
                    object_=response_format, annotation=ResponseFormat, direction="write"
                ),
                "max_tokens": max_tokens,
                "stream": False,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    NonStreamAnalyzeResponse,
                    parse_obj_as(
                        type_=NonStreamAnalyzeResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class EntityCollection(UniversalBaseModel):
    """
    An object that represents a collection of related entities.
    """

    id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="_id")] = pydantic.Field(default=None)
    """
    The unique identifier of the entity collection.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the entity collection.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    The description of the entity collection.
    """

    created_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The date and time, in RFC 3339 format (“YYYY-MM-DDTHH:mm:ssZ”), when the entity collection was created.
    """

    updated_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The date and time, in RFC 3339 format (“YYYY-MM-DDTHH:mm:ssZ”), when the entity collection was last updated.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .completed_chunk_proof_type import CompletedChunkProofType


class CompletedChunk(UniversalBaseModel):
    chunk_index: int = pydantic.Field()
    """
    The number that identifies which chunk you uploaded. When you received presigned URLs from the platform, each URL was assigned an index number. Use that same number. The chunks are numbered starting from 1.
    """

    proof: str = pydantic.Field()
    """
    The ETag value you received after uploading the chunk. When you upload a chunk to a presigned URLs, the response includes an ETag. Use this value and submit it as proof of successful upload.
    """

    proof_type: CompletedChunkProofType = pydantic.Field()
    """
    The verification method. Supported value: `etag`.
    """

    chunk_size: int = pydantic.Field()
    """
    The number of bytes uploaded for this chunk. For all chunks except the last, this value equals [`chunk_size`](/v1.3/api-reference/upload-content/multipart-uploads/create#response.body.chunk_size). For the last chunk, it may be smaller.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class VideosRetrieveResponseSystemMetadata(UniversalBaseModel):
    """
    System-generated metadata about the video.
    """

    duration: typing.Optional[float] = None
    filename: typing.Optional[str] = None
    fps: typing.Optional[float] = None
    height: typing.Optional[int] = None
    width: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class VideoSegmentationFixedFixed(UniversalBaseModel):
    duration_sec: int = pydantic.Field()
    """
    The duration in seconds for each segment.
    
    The platform divides the video into segments of this exact length. The final segment may be shorter if the video duration is not evenly divisible.
    
    **Example**: With `duration_sec: 5`, a 12-second video produces segments: [0-5s], [5-10s], [10-12s].
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import CreateEmbeddingsRequestInputType, CreateEmbeddingsRequestModelName
from . import tasks
from .tasks import (
    CreateAsyncEmbeddingRequestInputType,
    CreateAsyncEmbeddingRequestModelName,
    TasksCreateResponse,
    TasksCreateResponseStatus,
    TasksListResponse,
    TasksListResponsePageInfo,
)

__all__ = [
    "CreateAsyncEmbeddingRequestInputType",
    "CreateAsyncEmbeddingRequestModelName",
    "CreateEmbeddingsRequestInputType",
    "CreateEmbeddingsRequestModelName",
    "TasksCreateResponse",
    "TasksCreateResponseStatus",
    "TasksListResponse",
    "TasksListResponsePageInfo",
    "tasks",
]
